真爱至上 (豆瓣)
Description: 真爱至上电影简介和剧情介绍,真爱至上影评、图片、预告片、影讯、论坛、在线购票
Keywords: 真爱至上,Love Actually,真爱至上影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.190豆瓣电影Top250

# 真爱至上 Love Actually (2003)

导演: 理查德·柯蒂斯
编剧: 理查德·柯蒂斯
主演: 休·格兰特 / 科林·费尔斯 / 艾玛·汤普森 / 凯拉·奈特莉 / 连姆·尼森 / 托马斯·布罗迪-桑斯特 / 比尔·奈伊 / 马丁·弗瑞曼 / 劳拉·琳妮 / 艾伦·瑞克曼 / 克里斯·马歇尔 / 罗德里戈·桑托罗 / 罗温·艾金森 / 比利·鲍伯·松顿 / 玛汀·麦古基安 / 安德鲁·林肯 / 露西娅·莫尼斯 / 海克·玛卡琪
类型: 剧情 / 喜剧 / 爱情
官方网站: www.loveactually.com/
制片国家/地区: 英国 / 美国 / 法国
语言: 英语 / 葡萄牙语 / 法语
上映日期: 2003-09-07(多伦多电影节) / 2003-11-06(美国) / 2003-11-21(英国)
片长: 135分钟
又名: 真的恋爱了(港) / 爱是您，爱是我(台) / 真情角落 / 真爱 / Love Actually Is All Around
IMDb: tt0314331
豆瓣评分
引用
8.6
691932人评价
5星
46.2%
4星
38.2%
3星
13.8%
2星
1.4%
1星
0.4%
好于 97% 爱情片
好于 98% 喜剧片
想看 看过
评价:
推荐

## 真爱至上的剧情简介 · · · · · ·

这是一出10个爱情故事串成的喜剧杂烩：
失去母亲的小男孩终日郁郁寡欢，继父不知该如何安慰。当他得知继子喜欢上学校里最美的女孩，便热烈地鼓励儿子去追。小男孩为了赢得小女孩的关注，废寝忘食地练习架子鼓，只为了在圣诞节的晚会上能与她同台演出。勇敢的他，甚至为了最后的一记道别潇 洒地突破机场的安检区。
两个孩子的母亲面对了婚姻危机。丈夫感情出轨，把项链送给了别的女人，给她的，则仅是一张她热爱的女歌手的CD。她找了借口仓皇躲入卧室，在歌声中隐忍啜泣。转个身，又夸张地大笑着，迎向娇女爱子欢喜的面容。 丈夫最终幡然醒悟。
……
如此的小故事共有十出，温暖你我的心。 ©豆瓣

## 真爱至上的演职员 · · · · · · ( 全部 54 )

- 理查德·柯蒂斯 导演
- 休·格兰特 饰 The Prime Minister
- 科林·费尔斯 饰 Jamie
- 艾玛·汤普森 饰 Karen
- 凯拉·奈特莉 饰 Juliet
- 连姆·尼森 饰 Daniel

## 真爱至上的视频和图片 · · · · · · ( 预告片3 | 视频评论1 · 添加 | 图片1508 · 添加 )

## 真爱至上的获奖情况 · · · · · · ( 全部 )

- 第61届金球奖
- 电影类 最佳音乐/喜剧片(提名)

- 第61届金球奖
- 电影类 最佳编剧(提名)
- 理查德·柯蒂斯

- 第57届英国电影学院奖
- 电影奖 最佳英国影片(提名)
- 埃里克·菲尔纳 / 理查德·柯蒂斯 / 蒂姆·贝文 / 邓肯·肯沃西

## 喜欢这部电影的人也喜欢 · · · · · ·

  罗马假日

  恋恋笔记本

  爱在黎明破晓前

  诺丁山

  他其实没那么喜欢你

  甜蜜蜜

  傲慢与偏见

  泰坦尼克号

  重庆森林

  和莎莫的500天

我要写短评

## 真爱至上的短评 · · · · · · ( 全部 180899 条 )

热门 / 最新 / 好友

### 1966 有用 男娼起义 看过 2011-01-07 10:13:20

我最期待的那一对没有走到一起。

### 5140 有用 亵渎电影 看过 2011-12-24 23:48:55

我的圣诞必备，年年都是看这个，年年心情大不同，有时候一个人，有时候两个人，有时候一群人，今晚又是一个人，心里偶尔想着另一个人，偶尔想着一群人。★★★★★

### 5615 有用 大头绿豆 看过 2006-10-14 13:04:58

1、每当我对世局倍感忧虑时，就会想到希思罗机场的入境闸口。人们认为世界充满仇恨与贪婪，但我却不同意。在我看来爱无处不在，虽然未必来的轰轰烈烈，但是爱永远存在。父子，母女，夫妻，男朋友，女朋友，老朋友，当飞机撞上世贸大厦时，临终打出的电话，谈的不是报复，而都是爱。如果你肯留意，你会发现爱其实无处不在。love actually is all around.

### 3719 有用 安东 看过 2009-09-24 23:27:28

生活真美好，在电影里。

### 2055 有用 南国玫瑰 看过 2008-10-30 22:06:53

从头哭到尾，心里暖，而遍体生寒，寂寞无处隐身，生生将我蚕食。

> 更多短评 180899条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 真爱至上的影评 · · · · · · ( 全部 1908 条 )

热门 / 最新 / 好友
熊仔面 2007-01-16 23:41:52

## <真爱至上>中可爱的明星们

第一次看这部电影已是很久之前了,最近重温了一下发现好多演员都曾出现在我们的视线中,而他们在不同的作品中表现的又是同样的可爱,所以在下搜集了些他们的资料和照片,有不详尽或出现纰漏处请大家多多指教,同时感谢xiaoxiaohai给予的巨大的帮助~~ Billy Nighy-Bill Mack滑稽过... (展开)
1935 135 485回应 收起
jie 2005-12-04 15:43:14

## 请在圣诞给我温暖

机场 不停地微笑 拥抱 很多个 很多个 人们不停地微笑着 拥抱着 亲吻着 有感激 有喜悦的泪水 这是影片第一个镜头 每当我为这世界倍感沮丧之时 我就想起西思罗机场大门的那一幕 很多人都说我们的生活在一个仇恨与贪婪的世界 但我不认为如此 在我看来 爱就在你左右 这是影片第一... (展开)
1990 84 160回应 收起
野马青年 2020-01-21 11:18:39

## 真的没人想吐槽一下《真爱至上》里的性别观念吗？

这篇影评可能有剧透

每年圣诞节都是大家狂刷《真爱至上》的时候，每年这个时候都能看到朋友圈里一遍遍转发这部电影截图的朋友。 我也是在这种氛围的影响下怀着期待去看了这部电影，却被其中落后的性别观念噎住。 的确，我也承认这部电影中有许多令人感动的场景，但我们也应该注意到，这部电影是200... (展开)
827 133 147回应 收起
zhangvalor 2005-06-09 17:53:50

## Love Actually is All Around

Whenever I get gloomy with the state of the world, I think about the arrivals gate at Heathrow airport. General opinion makes out that we live in a world of hatred and greed, but I don't see that. Seems to me that love is everywhere. Often it's not particul... (展开)
525 38 70回应 收起
若昔难得 2006-02-14 23:46:39

## Did I mention I love you

我习惯在特定的日子看相关主题的电影，例如去年6月4日我看的是《蓝宇》的前45分钟。而2月14日虽然已经变成了一个非常商业化的日子，不过对于独自在家里看碟的人来说，这依然是一个可以用来纪念爱情的节日，所以我选择看《真爱至上》（Love Actually） 《真爱至上》的编剧和导... (展开)
370 23 64回应 收起
木棉冬睡了 2007-03-22 14:12:41

## 关于影片的删节 我的大马哈鱼

很舒服的影片 那么多的人 那么多的爱 围绕在周边 love is actually arround the Salmon 开始一直找不到影片长度 所以连片花 story teller MV也一并看了 删减的片段也看了 据导演自己说 原本片子原本有三小时又多少分钟的 后来因为只能保存两个小时左右的 就把跟影片没有多... (展开)
192 10 25回应 收起
蟹眠眠 2006-07-27 16:41:53

## 迷人的爱情骗局

鲁迅悲戚地说“这是一个无爱的人间。”自我看到这句话的那天起，它就成了我的信仰。这个电影摧毁了鲁迅的话。 喜欢Hugh Grant的样子才下了这部《love actually》的电影。Hugh Grant是世界上所有男人里面最适合用“迷人”两字来形容的。一个男人能得到那样的容貌和气质，他准是... (展开)
175 15 16回应 收起
霁色如晴 2008-04-14 14:26:09

## 并不如想象和评论中好！

老实说，在看这部片子的时候，几次都想不要再往下看了！因为感觉人物分散，情节也较散。围绕四五个人或者说四五对分别展开情节，给人感觉比较散乱。 最后的结局属于好莱坞式的，意料之中。但是，至少首相的感情生活完全是还没什么基础，就有这样一个好结局，有点牵强。 (展开)
171 47 66回应 收起
圣墟 2017-05-11 10:44:57

## 爱无处不在

就我个人而言，我最喜欢的就是这部影片可以如此温馨的氛围表现这样美好的主题“爱无处不在”，Love is actually all around.是的，爱无处不在，无论是亲情，友情还是爱情。 虽是各自独立的小故事，却表达了同一个主旨；虽是采用了不同的方式，却同时在传达同一种元素，那就是爱... (展开)
89 6 5回应 收起

> 更多影评 1908篇

添加新讨论

## 讨论区 · · · · · ·

关于小男孩和他的继父 | 来自醉生梦死也空 | 1 回应 | 2022-11-22 19:20:28
感觉没有说的那么好 | 来自今天也吃甜水面 | 4 回应 | 2022-11-18 13:19:20
年轻的Rick和Dan长得一毛一样 | 来自已注销 |  | 2022-11-14 02:48:58
原盘信息及幕后故事 | 来自lululuo | 3 回应 | 2022-11-04 20:08:59
豆瓣top250最弱电影之一 | 来自浮躁 | 33 回应 | 2022-10-21 14:15:50

> 去这部影片的讨论区（全部455条）

## 关于《真爱至上》的问题 · · · · · · ( 全部32个 )

- 为什么最后都是大家从飞机上下来？集体去了外地？？？？？ 2人回答
- 我来问一个秀逗的问题 ，“华生”的职业是什么。。。？ 3人回答

> 全部32个问题

## 在哪儿看这部电影 · · · · · ·

- 腾讯视频 VIP免费观看
- 爱奇艺视频 VIP免费观看
- 优酷视频 VIP免费观看
- 芒果TV VIP免费观看
- 哔哩哔哩 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【浪漫爱情轻喜】 (影志)
- 【内牛满面】 (影志)
- 【英国制造】 (影志)
- 我爱的文艺片 (有猫万事足)

## 谁在看这部电影 · · · · · ·

- pupuさん
  刚刚 想看
- Zephyr
  1分钟前 想看
- momo
  3分钟前 看过

979114人看过 / 324815人想看

订阅真爱至上的评论:
feed: rss 2.0